netapp_ontap.models.aggregate_space_block_storage API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_space_block_storage`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateSpaceBlockStorageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateSpaceBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregate_metadata: Size GET`

    Space used by different metafiles and internal operations inside the aggregate, in bytes.

    Example: 2655

  `aggregate_metadata_percent: Size GET`

    Aggregate metadata as a percentage.

    Example: 8

  `available: Size GET`

    Space available in bytes.

    Example: 10156560384

  `data_compacted_count: Size GET`

    Amount of compacted data in bytes.

    Example: 1990000

  `data_compaction_space_saved: Size GET`

    Space saved in bytes by compacting the data.

    Example: 1996000

  `data_compaction_space_saved_percent: Size GET`

    Percentage saved by compacting the data.

    Example: 27

  `full_threshold_percent: Size GET`

    The aggregate used percentage at which 'monitor.volume.full' EMS is generated.

  `inactive_user_data: Size GET`

    The size that is physically used in the block storage and has a cold temperature, in bytes. This property is only supported if the aggregate is either attached to a cloud store or can be attached to a cloud store. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either block_storage.inactive_user_data or **.

    Example: 304448

  `inactive_user_data_percent: Size GET`

    The percentage of inactive user data in the block storage. This property is only supported if the aggregate is either attached to a cloud store or can be attached to a cloud store. This is an advanced property; there is an added computational cost to retrieving its value. The field is not populated for either a collection GET or an instance GET unless it is explicitly requested using the fields query parameter containing either block_storage.inactive_user_data_percent or **.

  `physical_used: Size GET`

    Total physical used size of an aggregate in bytes.

    Example: 2461696

  `physical_used_percent: Size GET`

    Physical used percentage.

    Example: 50

  `size: Size GET`

    Total usable space in bytes, not including WAFL reserve and aggregate snapshot reserve.

    Example: 10156769280

  `used: Size GET`

    Space used or reserved in bytes. Includes volume guarantees and aggregate metadata.

    Example: 2088960

  `used_including_snapshot_reserve: Size GET`

    Total used including the snapshot reserve, in bytes.

    Example: 674685

  `used_including_snapshot_reserve_percent: Size GET`

    Total used including the Snapshot reserve as a percentage.

    Example: 35

  `used_percent: Size GET`

    Aggregate used percentage.

    Example: 50

  `volume_deduplication_shared_count: Size GET`

    Amount of shared bytes counted by storage efficiency.

    Example: 1990000

  `volume_deduplication_space_saved: Size GET`

    Amount of space saved in bytes by storage efficiency.

    Example: 1996000

  `volume_deduplication_space_saved_percent: Size GET`

    Percentage of space saved by storage efficiency.

    Example: 27

  `volume_footprints_percent: Size GET`

    A summation of volume footprints inside the aggregate, as a percentage. A volume's footprint is the amount of space being used for the volume in the aggregate.

    Example: 14